# Utilisation de SHEF

## Introduction

SHEF est une API permettant de gérer la saisie d'un texte en WYSIWYG, incluant une mise en forme basique.

Cette API est construite sur la base de SHEF développé par Bob Tantlinger et disponible sur 
https://sourceforge.net/projects/shef/

La licence d'usage est GNU/GPL verion 2 ou ultérieur, selon l'usage que vous en faites. 
En cas de réutilisation merci de signaler la source.  

## Programme de test

    java -jar SHEF.jar

## Utilisation de l'API

### Préalable

SHEF fournit un composant de type JPanel, elle est à utiliser dans une boîte de dialogue par exemple. 
(voir un exemple en fin de document)

### Initialisation

    SHEFEditor editor=new SHEFEditor();

Initialisation simple du composant. La barre d'outils comporte deux lignes et permet un ensemble de mis en forme complet.

    SHEFEditor editor=new SHEFEditor(int reduced);

Initialisation du composant avec une barre d'outils réduite à zéro, une ou deux ligne. Certaines mise en forme ne seront pas possible. 

    SHEFEditor editor=new SHEFEditor(int reduced, int lang);

Le guillemet est un signe typographique de ponctuation, principalement utilisé 
par paires d’un guillemet ouvrant et d’un guillemet fermant. Leurs formes 
(simple ou double, en chevron ou en apostrophe) et positions 
(gauche ou droite) varient selon les langues, les régions ou la direction du 
système d’écriture utilisé. Le principal usage des guillemets est de mettre 
en relief une expression, un terme ou une citation. (source https://fr.wikipedia.org/wiki/Guillemet)
Il est donc possible de sélectionner le type de guillemet dont des boutons de 
racourci seront disponible dans la barre d'outils. Paramètres par défaut: 
reduced=2, lang=3.

    SHEFEditor editor=new SHEFEditor(String param);

Permet d'initialiser l'éditeur via des paramètres explicites. Chaque paramètre 
est séparé du suivant par une virgule. Les paramètres sont:

- allow/disallow: autorise/interdit les notes de renvoi.
- none/reduced/full: barre d'outils (none=aucune, reduced=réduite, 
full=complète, sur deux lignes).
- lang_none/lang_en/lang_fr/lang_all: détermine la langue pour les signes 
d'ouverture et de fermeture d'un dialogue.

L'ordre des paramètres est indifférent. Le paramétrage par défaut est:
"full, lang_none, allow".
 
### Initaliser/Récupérer le texte

    void setText(String);

Le texte passé en paramètre intègre le code HTML utile.

    String getText();

Le résultat retourné intégrera le code HTML nécessaire.

### Exemple

    public class DEMO implements ActionListener {
	private SHEFEditor editor;
        private int mode=SHEFEditor.FULL, dlg_lang=SHEFEditor.DLG_ALL;

    	public static void main(String args[]) {
		SwingUtilities.invokeLater(() -> {
			SHEF demo = new SHEF();
			demo.init();
		});
	}

	public void init() {
		String texte="<p>Demo text for SHEF</p>";
		editor = new SHEFEditor("full, lang_all, allow);
		editor.setText(texte);
		editor.setCaretPosition(0);
		mainFrame = new JFrame();
		//mainFrame.setLayout(new BorderLayout());
		mainFrame.setVisible(true);
		mainFrame.setLocationRelativeTo(null);
		mainFrame.add(editor);
                System.out.println(editor.getText());
	}
    }


